@@ -1,12 +1,12 @@
 // -*-Mode: C++;-*-
 /*
- * $Id: MainApp.h,v 2.10 2001/04/08 12:24:47 ral Exp $
+ * $Id: MainApp.h,v 2.12 2003/02/04 00:08:53 ral Exp $
  */
 
 #ifndef CMainApp_included
 #define CMainApp_included
 
-#include "ktmainwindow.h"
+#include "kmainwindow.h"
 #include <qfile.h>
 #include <kmenubar.h>
 #include "sendmessage.h"
@@ -34,6 +34,8 @@ protected:
     KMenuBar*MenuBar;
     CMainWindow* MainWidget;
 
+    void initToolbar();
+
 protected slots:
     void new_window();
     void raus_hier();
