@@ -7,16 +7,19 @@
 #include "StatusView.h"
 #include "my_sql.h"
 #include "stringres.h"
-#include "settings.h"
+#include "kmysqladmin/setup/settings.h"
 #include <qtextview.h>
+#include <iostream>
 
 #ifndef rcsid
-static const char rcsid[]="$Id: StatusView.cpp,v 2.8 2001/04/08 12:24:47 ral Exp $";
+static const char rcsid[]="$Id: StatusView.cpp,v 2.10 2003/02/09 17:54:35 ral Exp $";
 //const char*statusview_rcs(){return rcsid;}
 #endif
 
 #define Inherited CTextViewData
 
+using namespace std;
+
 CStatusView::CStatusView(smart_pointer<CMySql>& _sql_server,QWidget* parent,const char* name)
     :Inherited( parent, name )
 {
@@ -43,14 +46,16 @@ void CStatusView::get_status()
     long seconds;
     QString s;
     QString t;
-    char *str1, *str2;
+    char*str2;
+    string str1;
 
-    str1 = str2 = NULL;
+    str1 = "";
+    str2 = NULL;
     if (!sql_server)
 	return;
     
     str1 = sql_server->get_status();
-    if (!str1)
+    if (str1.empty())
 	return;
     str2 = &str1[8];
     s = str2;
