@@ -16,18 +16,22 @@
  ***************************************************************************/
 
 #ifndef rcsid
-static const char rcsid[]="$Id: altertable.cpp,v 2.17 2001/04/08 16:40:05 ral Exp $";
+static const char rcsid[]="$Id: altertable.cpp,v 2.19 2003/02/04 00:08:53 ral Exp $";
+#endif
+
+#ifndef WIN32
+#include <kapp.h>
+#else
+#pragma warning (disable:4786)
 #endif
 
 #include <string>
 #include <qlist.h>
-//#include <kmsgbox.h>
-#include <kapp.h>
 #include <qmessagebox.h>
 #include "globals.h"
 #include "stringres.h"
 #include "my_sql.h"
-#include "stringhelper.h"
+#include "kmysqladmin/helpers/stringhelper.h"
 
 #include "altertable.h"
 #include <qcheckbox.h>                                                          
@@ -177,35 +181,39 @@ void CAlterTable::Modify_Column()
     old_name = desc_list[i].get_name();
 
     temp_desc.set_name(old_name);
-    c_iter = CurrentColumns.find(temp_desc);
+    c_iter = std::find(CurrentColumns.begin(),
+                       CurrentColumns.end(),
+                       temp_desc);
     t_change.columns.second = old_name;
     t_change.columns.first = "";
-    d_iter = DescrChanges.find_second(t_change);
+    d_iter = find_second(DescrChanges,t_change);
     if (!_modify_column()) {
 	return;
     }
     //first modify
-    if (c_iter && !d_iter) {
+    if (c_iter!=CurrentColumns.end() && d_iter==DescrChanges.end()) {
 	t_change.columns.first = old_name.c_str();
 	t_change.columns.second = n_name.c_str();
 	t_change.typ = change_type::mod;
 	DescrChanges.push_back(t_change);
       
-    } else if (d_iter && d_iter->columns.first.size()>0) {
+    } else if (d_iter!=DescrChanges.end() && d_iter->columns.first.size()>0) {
 	//some more modifies and / or renamed to original name
 	d_iter->columns.second = n_name;
 	d_iter->typ = change_type::mod;
-    } else if (!d_iter && !c_iter) {
+    } else if (d_iter==DescrChanges.end() && c_iter==CurrentColumns.end()) {
 	//possible first deleted
 	t_change.columns.first = n_name;
 	t_change.columns.second = "";
-	d_iter = DescrChanges.find(t_change);
-	if (d_iter) {
+	d_iter = std::find(DescrChanges.begin(),
+                           DescrChanges.end(),
+                           t_change);
+	if (d_iter!=DescrChanges.end()) {
 	    d_iter->columns.first = n_name;
 	    d_iter->columns.second = n_name;
 	    d_iter->typ = change_type::mod;
 	}
-    } else if (d_iter && d_iter->columns.first.size()==0) {
+    } else if (d_iter!=DescrChanges.end() && d_iter->columns.first.size()==0) {
 	d_iter->columns.second = n_name;
     }
 #ifndef NO_DEBUG
@@ -221,12 +229,14 @@ void CAlterTable::AddColumn()
     change_list::iterator d_iter;
     
     t_change.columns.first = n_name;
-    d_iter = DescrChanges.find(t_change);
+    d_iter = std::find(DescrChanges.begin(),
+                       DescrChanges.end(),
+                       t_change);
 
     if (!_add_column()) {
 	return;
     }
-    if (d_iter) {
+    if (d_iter!=DescrChanges.end()) {
 	//	d_iter->columns.first = n_name;
 	d_iter->columns.second = n_name;
 	d_iter->typ = change_type::mod;
@@ -258,12 +268,16 @@ void CAlterTable::Delete_Column()
     t_change.columns.second = "";
     t_change.typ = change_type::del;
     temp_desc.set_name(name);
-    c_iter = CurrentColumns.find(temp_desc);
-    if (c_iter) {
+    c_iter = std::find(CurrentColumns.begin(),
+                       CurrentColumns.end(),
+                       temp_desc);
+    if (c_iter!=CurrentColumns.end()) {
 	//ok - first check for possible modified keys
 	//deleting an original column
-	d_iter = DescrChanges.find(t_change);
-	if (d_iter) {
+	d_iter = std::find(DescrChanges.begin(),
+                           DescrChanges.end(),
+                           t_change);
+	if (d_iter!=DescrChanges.end()) {
 	    //we fiddled around 
 	    d_iter->columns.second = "";
 	    d_iter->typ = change_type::del;
@@ -274,8 +288,8 @@ void CAlterTable::Delete_Column()
     } else {
 	t_change.columns.first = "";
 	t_change.columns.second = name;
-	d_iter = DescrChanges.find_second(t_change);
-	if (d_iter) {
+	d_iter = find_second(DescrChanges,t_change);
+	if (d_iter!=DescrChanges.end()) {
 	    DescrChanges.erase(d_iter);
 	}
     }
