@@ -1,27 +1,33 @@
+#ifndef WIN32
 #include <kapp.h>
 #include "MainApp.h"
-#include <stdio.h>
-#include "cmdline.h"
 #include <kcmdlineargs.h>
 #include <klocale.h>
 #include <kaboutdata.h>
-#include <qstring.h>
 #include "config.h"
+static const char *description =I18N_NOOP("kmysqladmin");
+#else
+#include <qapp.h>
+#include "MainApp_win32.h"
+#endif
+#include <stdio.h>
+#include "kmysqladmin/helpers/cmdline.h"
+#include <qstring.h>
 
 #include "stringres.h"
 
 #ifndef rcsid
-static const char rcsid[]="$Id: app.cpp,v 2.9 2001/04/29 11:14:07 ral Exp $";
+static const char rcsid[]="$Id: app.cpp,v 2.12 2003/02/09 17:54:35 ral Exp $";
 //const char*app_rcs(){return rcsid;}
 #endif
-static const char *description =I18N_NOOP("kmysqladmin");
 
 int main(int argc, char **argv)
 {
+#ifndef WIN32
     QString about = i18n(CStringRes::get_string(59));
     about += "\n";
     about += i18n(CStringRes::get_string(60));
-    about += "\n2001-04-30";
+    about += "\n2003-02-10";
     
     KAboutData aboutData("kmysqladmin",I18N_NOOP("kmysqladmin"),
                          VERSION,description,KAboutData::License_GPL,
@@ -29,8 +35,13 @@ int main(int argc, char **argv)
     aboutData.addAuthor("Rajko Albrecht", "http://www.alwins-world.de","ral@alwins-world.de");
     KCmdLineArgs::init(argc, argv, &aboutData);
     KApplication a(argc, argv);
+#else
+    QApplication a( argc, argv );
+#endif
     CMainApp *dlg = new CMainApp("MainApp",true);
-    
+#ifdef WIN32
+    a.setMainWidget(dlg);
+#endif
     dlg->show();
     
     return a.exec();
