@@ -1,5 +1,5 @@
 #ifndef rcsid
-static const char rcsid[]="$Id: compoundkeydlg.cpp,v 2.13 2001/04/29 11:14:07 ral Exp $";
+static const char rcsid[]="$Id: compoundkeydlg.cpp,v 2.14 2003/02/04 00:08:53 ral Exp $";
 //const char*compoundkeydlg_rcs(){return rcsid;}
 #endif
 
@@ -71,7 +71,7 @@ void CCompoundKeyDlg::AddKey()
 	return;
     temp_key.set_name(name);
 
-    if (int_key_list->find(temp_key)) {
+    if (std::find(int_key_list->begin(),int_key_list->end(),temp_key)!=int_key_list->end()) {
 	QString info;
 	info = GET_TEXT(0);
 	info+=" ";
@@ -83,7 +83,12 @@ void CCompoundKeyDlg::AddKey()
     }
     temp_key.set_compound(true);
     int_key_list->push_back(temp_key);
-    CurrentKey = int_key_list->end()-1;
+    int j = int_key_list->size()-1;
+    CurrentKey = (&(*int_key_list)[j]);
+#if 0
+    CurrentKey = --(int_key_list->end());
+#endif
+    //CurrentKey = int_key_list->rbegin();
     KeysList->insertItem(name);
     
     KeysList->setCurrentItem(KeysList->count()-1);
@@ -106,8 +111,10 @@ void CCompoundKeyDlg::DeleteKey()
 	return;
     KeyList_iterator key_iterator;
     for (key_iterator = int_key_list->begin(); key_iterator != int_key_list->end();++key_iterator) {
+#if 0
 	find_key = key_iterator;
-	if (*find_key == name) {
+#endif
+	if (*key_iterator == name) {
 	    key_iterator = int_key_list->erase(key_iterator);
 	    KeysList->removeItem(pos);
 	    return;
@@ -158,7 +165,7 @@ void CCompoundKeyDlg::KeyFieldSelected(int which)
 	    break;
 	}
     }
-    CurrentKey = key_iterator;
+    CurrentKey = &(*key_iterator);
     if (key_iterator == int_key_list->end()) {
 	CurrentKey = 0;
 	return;
