@@ -1,6 +1,6 @@
 // -*-Mode: C++;-*- 
 /*
- * $Id: compoundkeydlg.h,v 2.2 1999/10/16 16:23:16 ral Exp $
+ * $Id: compoundkeydlg.h,v 2.3 2001/04/14 10:56:03 ral Exp $
  */
 
 #ifndef CCompoundKeyDlg_included
@@ -26,7 +26,7 @@ protected slots:
     virtual void TableColumnsSelected(int);
     virtual void AddToKey();
     virtual void KeyColumnsSelected(int);
-    virtual void KeyNameChanged(const char*);
+    virtual void KeyNameChanged(const QString&);
     virtual void PrimarySelected();
     virtual void RemoveFromKey();
 
