@@ -1,13 +1,15 @@
 #include <qstring.h>
 #include <qlist.h>
-//#include <kmsgbox.h>
+
+#ifndef WIN32
 #include <kapp.h>
+#endif
+
 #include <qmessagebox.h>
 
 #include "createtable.h"
 #include "tabledescr.h"
 #include "globals.h"
-//#include "compoundkeydlg.h"
 #include "stringres.h"
 #include "my_sql.h"
 #include <qcheckbox.h>                                                          
@@ -27,7 +29,7 @@
 
 
 #ifndef rcsid
-static const char rcsid[]="$Id: createtable.cpp,v 2.19 2001/04/08 14:00:03 ral Exp $";
+static const char rcsid[]="$Id: createtable.cpp,v 2.21 2003/02/04 00:08:53 ral Exp $";
 //const char*createtable_rcs(){return rcsid;}
 #endif
 
@@ -62,7 +64,7 @@ CCreateTable::~CCreateTable()
 void CCreateTable::TableTextChanged(const QString&text)
 {
     bool how =  (text.length()>0 &&
-		 (CurrentTables.find(text.latin1()) == 0) );
+		 (CurrentTables.find(text.latin1()) == CurrentTables.end()) );
     if (sql_server->is_system_db(DBList->currentText().latin1())) {
 	how = false;
     }
@@ -90,14 +92,14 @@ void CCreateTable::AddColumn()
 
     CColumnDescriptor Desc;
     Desc.set_name(ColumnNameEdit->text());
-    if (desc_list.find(Desc)!=0) {
+    if (std::find(desc_list.begin(),desc_list.end(),Desc)!=desc_list.end()) {
 	QMessageBox::critical(this,CStringRes::get_string(6),
 			      CStringRes::get_string(7));
 	return;
     }
     if (Primary_Key->isEnabled() && Primary_Key->isChecked()) {
 	Key.set_name("PRIMARY");
-	if (key_list.find(Key)) {
+	if (std::find(key_list.begin(),key_list.end(),Key)!=key_list.end()) {
 	    QMessageBox::critical(this,CStringRes::get_string(6),
 				  CStringRes::get_string(8));
 	    return;
