@@ -1,6 +1,6 @@
 // -*-Mode: C++;-*- 
 /*
- * $Id: createtable.h,v 2.11 2001/04/08 14:00:03 ral Exp $
+ * $Id: createtable.h,v 2.12 2003/02/04 00:08:53 ral Exp $
  */
 #ifndef CCreateTable_included
 #define CCreateTable_included
@@ -9,7 +9,7 @@
 #include <qlined.h>
 #include <qlist.h>
 #include "tabledescr.h"
-#include "stringlist.h"
+#include "kmysqladmin/helpers/stringlist.h"
 
 class CMySql;
 
