@@ -1,10 +1,16 @@
+#ifndef WIN32
 #include <kapp.h>
 #include "MainApp.h"
+#else
+#include "MainApp_win32.h"
+#endif
+
 #include "globals.h"
 #include <qstring.h>
 #include <qregexp.h>
+#include "kmysqladmin/setup/settings.h"
 
 #ifndef rcsid
-static const char rcsid[]="$Id: globals.cpp,v 2.6 1999/11/07 15:42:05 ral Exp $";
+static const char rcsid[]="$Id: globals.cpp,v 2.8 2003/02/04 00:08:53 ral Exp $";
 //const char*globals_rcs(){return rcsid;}
 #endif
