@@ -1,17 +1,20 @@
 #include <qlist.h>
 #include <qstrlist.h>
 #include <qlabel.h>
+#include <qstring.h>
 
 #include "PatternPair.h"
 #include "grantedit.h"
 
 #ifndef rcsid
-static const char rcsid[]="$Id: grantedit.cpp,v 2.7 2001/04/08 12:27:41 ral Exp $";
+static const char rcsid[]="$Id: grantedit.cpp,v 2.9 2003/02/04 00:08:53 ral Exp $";
 //const char*grantedit_rcs(){return rcsid;}
 #endif
 
 #define Inherited CGrantEditData
 
+using namespace std;
+
 CGrantEdit::CGrantEdit(QWidget* parent,	const char* name)
     :Inherited( parent, name )
 {
