@@ -6,10 +6,12 @@
 #include <qlist.h>
 #include <qlined.h>
 #include <qlayout.h>
+#include <qcheckbox.h>
+#include <qpushbutton.h>
 
 #include "granteditdata.h"
 #include "PatternPair.h"
-#include "stringlist.h"
+#include "kmysqladmin/helpers/stringlist.h"
 
 class CGrantEdit : public CGrantEditData
 {
