@@ -1,7 +1,11 @@
+#ifndef WIN32
+#include <kapp.h>
+#else
+#pragma warning (disable:4786)
+#endif
+
 #include <qstring.h>
 #include <qlist.h>
-//#include <kmsgbox.h>
-#include <kapp.h>
 #include <qmessagebox.h>
 
 #include "modifytable.h"
@@ -27,7 +31,7 @@
 #include <qwhatsthis.h>
 
 #ifndef rcsid
-static const char rcsid[]="$Id: modifytable.cpp,v 2.26 2001/04/14 10:56:03 ral Exp $";
+static const char rcsid[]="$Id: modifytable.cpp,v 2.28 2003/02/04 00:08:53 ral Exp $";
 //const char*modifytable_rcs(){return rcsid;}
 #endif
 
@@ -229,7 +233,7 @@ void CModifyTable::SetTypeInt(int DataType)
 void CModifyTable::TableTextChanged(const QString&text)
 {
     bool how =  (text.length()>0 &&
-		 (CurrentTables.find(text.latin1()) == 0) );
+		 (CurrentTables.find(text.latin1()) == CurrentTables.end()) );
     ColumnNameEdit->setEnabled(how);
     AddButton->setEnabled( how && ColumnNameEdit->text().length()>0 );
 }
@@ -382,14 +386,14 @@ bool CModifyTable::_add_column()
 
     CColumnDescriptor Desc;
     Desc.set_name(ColumnNameEdit->text());
-    if (desc_list.find(Desc)!=0) {
+    if (std::find(desc_list.begin(),desc_list.end(),Desc)!=desc_list.end()) {
 	QMessageBox::critical(this,CStringRes::get_string(6),
 			      CStringRes::get_string(7));
 	return false;
     }
     if (Primary_Key->isEnabled() && Primary_Key->isChecked()) {
 	Key.set_name("PRIMARY");
-	if (key_list.find(Key)) {
+	if ( std::find(key_list.begin(),key_list.end(),Key)!=key_list.end()) {
 	    QMessageBox::critical(this,CStringRes::get_string(6),
 				  CStringRes::get_string(8));
 	    return false;
@@ -511,8 +515,8 @@ bool CModifyTable::_modify_column()
 	return false;
     if (Primary_Key->isEnabled() && Primary_Key->isChecked()) {
 	Key.set_name("PRIMARY");
-	KeyList_iterator iter = key_list.find(Key);
-	if (iter) {
+	KeyList_iterator iter = std::find(key_list.begin(),key_list.end(),Key);
+	if (iter!=key_list.end()) {
 	    if (!iter->contains_column_name(desc_list[i].get_name())) {
 		if (!iter->contains_column_name(desc_list[i].get_name())) {
 		    QMessageBox::critical(this,CStringRes::get_string(9),
@@ -526,7 +530,9 @@ bool CModifyTable::_modify_column()
 
     if (Desc != desc_list[i]) {
 	// check for duplicates if name has changed
-	if (desc_list.find(Desc)!=0) {
+	if ( std::find(desc_list.begin(),
+                       desc_list.end(),
+                       Desc) != desc_list.end()) {
 	    QMessageBox::critical(this,CStringRes::get_string(9),
 				  CStringRes::get_string(7));
 	    return false;
@@ -585,8 +591,15 @@ void CModifyTable::Build_Compound()
 
 void CModifyTable::AddEnum()
 {
-    if (enums.find(EnumList->currentText().latin1()))
+#if 0
+    if ( std::find(enums.begin(),
+                   enums.end(),
+                   EnumList->currentText().latin1()) !=
+         enums.end())
 	return;
+#endif
+    if (enums.find(EnumList->currentText().latin1())!=enums.end())
+        return;
     QString current = EnumList->currentText();
     EnumList->insertItem(current,0);
     enums.push_back(std::string(EnumList->currentText()));
@@ -598,7 +611,7 @@ void CModifyTable::DelEnum()
 	return;
     int i = EnumList->currentItem();
     stringIlist::iterator iter = enums.find(EnumList->currentText().latin1());
-    if (iter)
+    if (iter!=enums.end())
 	enums.erase(iter);
     if (i == -1)
 	return;
