@@ -1,3 +1,6 @@
+#include "config.h"
+
+#ifdef HAVE_MYSQL_LIBS
 #ifdef WIN32
 #pragma warning ( disable : 4786 )
 #pragma warning ( disable : 4800 )
@@ -11,22 +14,24 @@
 #include <string.h>
 #include <mysql_com.h>
 #include <cmath>
+#include <iostream>
 
 #ifndef WIN32
 #include <sys/time.h>
 #include <unistd.h> 
 #endif
 
-#include <strstream>
+#include <sstream>
 
 #include "change_type.h"
-#include "specials.h"
-#include "stringhelper.h"
+#include "helpers/specials.h"
 
 #ifndef rcsid
-static const char rcsid[]="$Id: my_sql.cpp,v 2.51 2001/04/23 22:48:30 ral Exp $";
+static const char rcsid[]="$Id: my_sql.cpp,v 2.53 2003/02/04 00:08:53 ral Exp $";
 #endif
 
+using namespace std;
+
 const char* CMySql::MessageArray[]={
     "row(s) affected",              //0
     "row(s) found",
@@ -35,40 +40,42 @@ const char* CMySql::MessageArray[]={
     "Not connected",
     "I do not change system database in this way", //5
     "No database given to work on",
+    "Could not connect to database",
+    "Error while escaping string"
 };
 
 int CMySql::MessageCount = 5;
 
 const my_sql_type CMySql::f_arr[]=
-{   //                                                             def  aut   zer   uns  key   keys  enums binary
-    my_sql_type("TINYINT","TinyInt (1 Byte)",          1,  3,0,0, true, true, true, true,false, true,false,false),
-    my_sql_type("SMALLINT","SmallInt (2 Bytes)",       1,  5,0,0, true, true, true, true,false, true,false,false),
-    my_sql_type("MEDIUMINT","MediumInt (3 Bytes)",     1,  8,0,0, true, true, true, true,false, true,false,false),
-    my_sql_type("INT","Int (4 Bytes)",                 1, 10,0,0, true, true, true, true,false, true,false,false),
-    my_sql_type("BIGINT","BigInt (8 Bytes)",           1, 20,0,0, true, true, true, true,false, true,false,false),
-    my_sql_type("FLOAT","Float (4 Bytes)",             1, 20,0,4, true, true, true,false,false, true,false,false),
-    my_sql_type("REAL","Double (8 Bytes)",             1, 20,0,8, true, true, true,false,false, true,false,false),
-    my_sql_type("DECIMAL","Decimal (lenght,dec)",      1, 20,0,8, true, true, true,false, true, true,false,false),
-    my_sql_type("CHAR","Char (1 <= num <=255)",        1,255,0,0,false,false,false,false, true, true,false, true),
-    my_sql_type("VARCHAR","Varchar (1 <= num <=255)",  1,255,0,0,false,false,false,false, true, true,false, true),
-    my_sql_type("TINYBLOB","Tinyblob (num <= 255)",    2,  2,0,0,false,false,false,false,false,false,false,false), //10
-    my_sql_type("BLOB","Blob (num <= 65535)",          2,  2,0,0,false,false,false,false,false,false,false,false),
-    my_sql_type("MEDIUMBLOB","Mediumblob (num < 2^24)",2,  2,0,0,false,false,false,false,false,false,false,false),
-    my_sql_type("LONGBLOB","Longblob (num < 2^32)",    2,  2,0,0,false,false,false,false,false,false,false,false),
-    my_sql_type("TINYTEXT","Tinytext (num <= 255)",    2,  2,0,0,false,false,false,false,false,false,false,false),
-    my_sql_type("TEXT","Text (num <= 65535)",          2,  2,0,0,false,false,false,false,false,false,false,false),
-    my_sql_type("MEDIUMTEXT","Mediumtext (num < 2^24)",2,  2,0,0,false,false,false,false,false,false,false,false),
-    my_sql_type("LONGTEXT","Longtext (num < 2^32)",    2,  2,0,0,false,false,false,false,false,false,false,false),
-    my_sql_type("TIMESTAMP","Timestamp (4 Bytes)",     1, 14,0,0, true,false,false,false,false, true,false,false),
-    my_sql_type("DATE","Date (4 Bytes)",              10, 10,0,0, true,false,false,false,false, true,false,false),
-    my_sql_type("TIME","Time (3 Bytes)",               8,  8,0,0, true,false,false,false,false, true,false,false), //20
-    my_sql_type("ENUM","Enum",                         1, 80,0,0, true,false,false,false,false, true, true,false),
-    my_sql_type("SET","Set",                           1, 80,0,0, true,false,false,false,false, true, true,false),
-    my_sql_type("DATETIME","DateTime",                14, 14,0,0,false,false,false,false,false,false,false,false),
-    my_sql_type("YEAR","Year",                         4,  4,0,0, true,false,false,false,false,false,false,false),
-    my_sql_type("DOUBLE","Double (8 Bytes)",           1, 20,0,8, true, true, true,false,false, true,false,false),
-    my_sql_type("NUMERIC","Decimal (lenght,dec)",      1, 20,0,8, true, true, true,false, true, true,false,false),
-};
+    {   //                                                             def  aut   zer   uns  key   keys  enums binary
+        my_sql_type("TINYINT","TinyInt (1 Byte)",          1,  3,0,0, true, true, true, true,false, true,false,false),
+        my_sql_type("SMALLINT","SmallInt (2 Bytes)",       1,  5,0,0, true, true, true, true,false, true,false,false),
+        my_sql_type("MEDIUMINT","MediumInt (3 Bytes)",     1,  8,0,0, true, true, true, true,false, true,false,false),
+        my_sql_type("INT","Int (4 Bytes)",                 1, 10,0,0, true, true, true, true,false, true,false,false),
+        my_sql_type("BIGINT","BigInt (8 Bytes)",           1, 20,0,0, true, true, true, true,false, true,false,false),
+        my_sql_type("FLOAT","Float (4 Bytes)",             1, 20,0,4, true, true, true,false,false, true,false,false),
+        my_sql_type("REAL","Double (8 Bytes)",             1, 20,0,8, true, true, true,false,false, true,false,false),
+        my_sql_type("DECIMAL","Decimal (lenght,dec)",      1, 20,0,8, true, true, true,false, true, true,false,false),
+        my_sql_type("CHAR","Char (1 <= num <=255)",        1,255,0,0,false,false,false,false, true, true,false, true),
+        my_sql_type("VARCHAR","Varchar (1 <= num <=255)",  1,255,0,0,false,false,false,false, true, true,false, true),
+        my_sql_type("TINYBLOB","Tinyblob (num <= 255)",    2,  2,0,0,false,false,false,false,false,false,false,false), //10
+        my_sql_type("BLOB","Blob (num <= 65535)",          2,  2,0,0,false,false,false,false,false,false,false,false),
+        my_sql_type("MEDIUMBLOB","Mediumblob (num < 2^24)",2,  2,0,0,false,false,false,false,false,false,false,false),
+        my_sql_type("LONGBLOB","Longblob (num < 2^32)",    2,  2,0,0,false,false,false,false,false,false,false,false),
+        my_sql_type("TINYTEXT","Tinytext (num <= 255)",    2,  2,0,0,false,false,false,false,false,false,false,false),
+        my_sql_type("TEXT","Text (num <= 65535)",          2,  2,0,0,false,false,false,false,false,false,false,false),
+        my_sql_type("MEDIUMTEXT","Mediumtext (num < 2^24)",2,  2,0,0,false,false,false,false,false,false,false,false),
+        my_sql_type("LONGTEXT","Longtext (num < 2^32)",    2,  2,0,0,false,false,false,false,false,false,false,false),
+        my_sql_type("TIMESTAMP","Timestamp (4 Bytes)",     1, 14,0,0, true,false,false,false,false, true,false,false),
+        my_sql_type("DATE","Date (4 Bytes)",              10, 10,0,0, true,false,false,false,false, true,false,false),
+        my_sql_type("TIME","Time (3 Bytes)",               8,  8,0,0, true,false,false,false,false, true,false,false), //20
+        my_sql_type("ENUM","Enum",                         1, 80,0,0, true,false,false,false,false, true, true,false),
+        my_sql_type("SET","Set",                           1, 80,0,0, true,false,false,false,false, true, true,false),
+        my_sql_type("DATETIME","DateTime",                14, 14,0,0,false,false,false,false,false,false,false,false),
+        my_sql_type("YEAR","Year",                         4,  4,0,0, true,false,false,false,false,false,false,false),
+        my_sql_type("DOUBLE","Double (8 Bytes)",           1, 20,0,8, true, true, true,false,false, true,false,false),
+        my_sql_type("NUMERIC","Decimal (lenght,dec)",      1, 20,0,8, true, true, true,false, true, true,false,false),
+    };
 
 const my_sql_type&CMySql::sql_type(int i)
 {
@@ -115,16 +122,17 @@ void CMySql::sql_disconnect()
 }
 
 CMySql::CMySql()
-    :refCounter()
+    :ref_count()
 {
     Sql_Connection = 0L;
     nothing_else = 0;
     Server_MasterVersion = Server_MinorVersion = Server_PatchLevel = 0;
     m_Host = m_Pass = m_User = m_Port = "";
+    message_call_back = 0;
 }
 
 CMySql::CMySql(const CMySql&old)
-    :refCounter()
+    :ref_count()
 {
     Sql_Connection = 0L;
     nothing_else = 0;
@@ -183,7 +191,9 @@ void CMySql::sql_connect(const char*host,const char*user,const char*pass,const c
             }
         }
     } else {
-	do_message(FormatSTLString("Couldn't connect: %s",mysql_error(Sql_Connection)));
+        stringstream s;
+        s << "Couldn't connect: " << mysql_error(Sql_Connection);
+	do_message(s.str());
 	delete Sql_Connection;
 	Sql_Connection = 0;
     }
@@ -241,12 +251,16 @@ const std::string&CMySql::get_info()
             p_info = mysql_get_proto_info(Sql_Connection);
             s_info = mysql_get_server_info(Sql_Connection);
 #ifndef WIN32
-            connect_info = FormatSTLString("%s\n%s %s\nProtokoll Version: %i\nServerversion: %s",
-		    h_info,t_1,c_info,p_info,s_info);
+            string sep = "\n";
 #else
-            connect_info = FormatSTLString("%s\r\n%s %s\r\nProtokoll Version: %i\r\nServerversion: %s",
-		    h_info,t_1,c_info,p_info,s_info);
+            string sep = "\r\n";
 #endif
+            stringstream s;
+            s << h_info << sep
+              << t_1 << " " << c_info << sep 
+              << "Protokoll Version: " << p_info << sep
+              << "Serverversion: " << s_info;
+            connect_info = s.str();
         }
         else {
             connect_info = "Couldn't get info";
@@ -255,15 +269,15 @@ const std::string&CMySql::get_info()
     return connect_info;
 }
 
-char*CMySql::get_status()
+string CMySql::get_status()
 {
-    char * Message;
-    char * Fehler;
+    string Message;
+    string Fehler;
     if (nothing_else || !Sql_Connection)
-        return 0;
+        return "";
     Message = mysql_stat(Sql_Connection);
     Fehler = get_last_error();
-    if (Fehler[0] != 0)
+    if (Fehler.size()>0)
         do_message(Fehler);
     return Message;
 }
@@ -325,9 +339,9 @@ bool CMySql::get_threads(list_vector&target)const
 }
 
 /*
-* retrieves the list of databases in the current
-* connected server
-*/
+ * retrieves the list of databases in the current
+ * connected server
+ */
 bool CMySql::get_db_list(const char*pattern,stringlist&target)const
 {
     target.resize(0);
@@ -409,8 +423,8 @@ bool CMySql::get_table_fields(const char*db,const char*table,ColumnList&target)c
         return false;
 
     if (!db) {
-		do_message(MessageArray[6]);
-		return false;
+        do_message(MessageArray[6]);
+        return false;
     }
     if (connect_db(db)!=0) {
         do_message("Could not connect to database");
@@ -453,9 +467,9 @@ bool CMySql::get_table_fields(const char*db,const char*table,ColumnList&target)c
 	    }
 	}
 	if (f_type == FieldDescriptCounts()) {
-		do_message("Error retrieving fieldtypes - please send a mail to the "
-				"autor of the software!");
-		return false;
+            do_message("Error retrieving fieldtypes - please send a mail to the "
+                       "autor of the software!");
+            return false;
 	}
 	my_sql_type t_info = sql_type(f_type);
 	if (f_type > 10 && f_type < 18) {
@@ -548,12 +562,16 @@ int CMySql::kill_thread(unsigned long pid)
     return i;
 }
 
-char*CMySql::get_last_error()const
+string CMySql::get_last_error()const
 {
+    char*f;
     if (!Sql_Connection) {
-        return "No connection";
+        return string("No connection");
     }
-    return mysql_error(Sql_Connection);
+    f = mysql_error(Sql_Connection);
+    if (!f || f[0]==0)
+        return string("");
+    return string(f);
 }
 
 /*
@@ -562,7 +580,7 @@ char*CMySql::get_last_error()const
 int CMySql::create_db(const char*db)
 {
     int i = 0;
-    const char*f;
+    string f;
     if (!db || !Sql_Connection || nothing_else)
         return -1;
     i = mysql_create_db(Sql_Connection,db);
@@ -578,9 +596,10 @@ bool CMySql::create_table(const char*db,const char*name,ColumnList*columns,KeyLi
 {
     std::string statement;
     std::string temp_statement;
+    stringstream s;
 	
-    ColumnList_iterator desc = NULL;
-    KeyList_iterator key = NULL;
+    ColumnList_iterator desc = columns->end();
+    KeyList_iterator key = keys->end();
     unsigned int count = 0;
     std::string Type;
 
@@ -663,7 +682,9 @@ bool CMySql::create_table(const char*db,const char*name,ColumnList*columns,KeyLi
                 statement+=iter->first.c_str();
                 if (iter->second > 0) {
                     statement+="(";
-                    statement+= FormatSTLString("%u",iter->second);
+                    s.str("");
+                    s << iter->second;
+                    statement+= s.str();
                     statement+=")";
                 }
             }
@@ -682,8 +703,8 @@ bool CMySql::create_table(const char*db,const char*name,ColumnList*columns,KeyLi
 }
 
 int CMySql::_fetch_rows(const char*db,const char*table,const char*sort_by,
-                   stringlist*which,unsigned int offset,unsigned int count,
-                   PatternList*Pattern,bool errors_only,MYSQL_RES**Res)
+                        stringlist*which,unsigned int offset,unsigned int count,
+                        PatternList*Pattern,bool errors_only,MYSQL_RES**Res)
 {
     std::string query;
     std::string entry;
@@ -747,8 +768,11 @@ int CMySql::_fetch_rows(const char*db,const char*table,const char*sort_by,
     if (count > 0 || offset > 0) {
         std::string ls;
         std::string cs;
+        stringstream ss;
         if (offset > 0) {
-            ls = FormatSTLString("LIMIT %u",offset);
+            ss.str("");
+            ss << "LIMIT "<<offset;
+            ls = ss.str();
             if (count > 0) {
                 ls+=",";
             }
@@ -759,7 +783,9 @@ int CMySql::_fetch_rows(const char*db,const char*table,const char*sort_by,
             ls = "LIMIT ";
         }
         if (count > 0) {
-            ls+= FormatSTLString("%u",count);
+            ss.str("");
+            ss << count;
+            ls+= ss.str();
         }
         query+=ls;
     }
@@ -818,7 +844,11 @@ int CMySql::fetch_rows(const char*db,const char*table,const char*sort_by,
 
     //what did the server found?
     unsigned long zaehler = Res->row_count;
-    if (!errors_only) do_message(FormatSTLString("%lu %s",zaehler,MessageArray[1]));
+    if (!errors_only) {
+        stringstream ss;
+        ss << zaehler << " " << MessageArray[1];
+        do_message(ss.str());
+    }
     std::string entry,query;
     entry = "";query = "";
     std::string helper = "";
@@ -838,8 +868,8 @@ int CMySql::fetch_rows(const char*db,const char*table,const char*sort_by,
             // for instance a query to the user rights
             if (which->size() == 0) {
                 /*                if (sizes) {
-                    sizes->push_back(FormatSTLString("%i",Field->max_length));
-                }
+                                  sizes->push_back(FormatSTLString("%i",Field->max_length));
+                                  }
                 */
                 if ( Pattern ) {
                     Pattern->push_back(CPatternPair(Field->name,query));
@@ -894,7 +924,11 @@ int CMySql::fetch_rows(const char*db,const char*table,const char*sort_by,
 
     //what did the server found?
     unsigned long zaehler = Res->row_count;
-    if (!errors_only) do_message(FormatSTLString("%lu %s",zaehler,MessageArray[1]));
+    if (!errors_only) {
+        stringstream ss;
+        ss << zaehler << " " << MessageArray[1];
+        do_message(ss.str());
+    }
     std::string query;
     query = "";
     stringlist helper,entry;
@@ -915,8 +949,8 @@ int CMySql::fetch_rows(const char*db,const char*table,const char*sort_by,
             // for instance a query to the user rights
             if (which->size() == 0) {
                 /*                if (sizes) {
-                    sizes->push_back(FormatSTLString("%i",Field->max_length));
-                    }*/
+                                  sizes->push_back(FormatSTLString("%i",Field->max_length));
+                                  }*/
                 if ( Pattern ) {
                     Pattern->push_back(CPatternPair(Field->name,query));
                 }
@@ -943,14 +977,14 @@ int CMySql::fetch_rows(const char*db,const char*table,const char*sort_by,
 /*
  * inserts a single row into a table
  */
-int CMySql::insert_row(const char*db,const char*table, PatternList*Pattern)
+int CMySql::insert_replace_row(const std::string what,const char*db,const char*table, PatternList*Pattern)
 {
-    std::string query = "";
-    std::string value_string = "";
-    std::string row_string = "";
-
-    std::string escaped;
+    stringstream query("");
+    stringstream value_string("");
+    stringstream row_string("");
+    string escaped="";
     int i;
+    
     if (!Sql_Connection) {
         do_message(MessageArray[4]);
         return -1;
@@ -963,51 +997,52 @@ int CMySql::insert_row(const char*db,const char*table, PatternList*Pattern)
         do_message(MessageArray[3]);
         return -1;
     }
-    if (!db)
-	return -1;
-    i = connect_db(db);
-    if (i < 0)
-	return i;
+    if (db || strlen(db)) {
+        i = connect_db(db);
+        if (i < 0) {
+            do_message(MessageArray[6]);
+            return i;
+        }
+    }
     //build the pattern-string
     PatternIterator p_iter;
     for (p_iter = Pattern->begin();p_iter!=Pattern->end();++p_iter){
-        if (value_string.empty()) {
-            value_string = "\'";
+        escaped="";
+        if (strlen(p_iter->get_pattern())) {
             do_escape(p_iter->get_pattern(),escaped);
-            if (!escaped.size())
+            if (!escaped.size()) {
+                do_message(MessageArray[8]);
                 return -1;
-            value_string += escaped;
-            value_string+="\'";
-            row_string = p_iter->get_entry();
+            }
         }
-        else {
-            value_string+=",\'";
-            do_escape(p_iter->get_pattern(),escaped);
-            if (!escaped.size())
-                return -1;
-            value_string+=escaped;
-            value_string+="\'";
-            row_string+=",";row_string+=p_iter->get_entry();
+        if (value_string.str().empty()) {
+            value_string << "\'";
+        } else {
+            value_string<<",\'";
+            row_string<<",";
         }
+        value_string << escaped << "\'";
+        row_string << p_iter->get_entry();
     }
     //build the complete query
-    query = "INSERT INTO ";
-    //query+=db;query+=".";
-    query+=table;query+=" (";query+=row_string;query+=") VALUES (";
-    query+= value_string;query+=")";
+    query << what << " INTO "
+          << table << " (" << row_string.str() << ") VALUES ("
+          << value_string.str() << ")";
     //send it to the protocoll
-    do_message(query.c_str());
+    do_message(query.str());
     //do it
-    i = mysql_query(Sql_Connection,query.c_str());
+    i = mysql_query(Sql_Connection,query.str().c_str());
     if (i == -1) {
-        //if some goes wrong 
-        query = mysql_error(Sql_Connection);
-        do_message(query.c_str());
+        //if some goes wrong
+        query.str(mysql_error(Sql_Connection));
+        do_message(query.str());
         return i;
     }
     //should be > 0 
     i = mysql_affected_rows(Sql_Connection);
-    do_message(FormatSTLString("%i %s",i,MessageArray[0]));
+    stringstream ss;
+    ss << i << " " << MessageArray[0];
+    do_message(ss.str());
     return i;
 }
 
@@ -1070,7 +1105,6 @@ int CMySql::update_row(const char*db,const char*table,
     if (i < 0)
 	return i;
     request = "UPDATE ";
-    //request+=db;request+=".";
     request+= table;request+=" SET ";
     PatternIterator p_iter;
     for (p_iter = to_change->begin();p_iter != to_change->end();++p_iter) {
@@ -1082,7 +1116,6 @@ int CMySql::update_row(const char*db,const char*table,
         request+="\'";
     }
     request+=MessageArray[2];
-    //    request+= " WHERE ";
     for (p_iter = identifiers->begin();p_iter != identifiers->end();++p_iter) {
         if (p_iter != identifiers->begin())
             request += " AND ";
@@ -1101,7 +1134,9 @@ int CMySql::update_row(const char*db,const char*table,
     //should be >= 0 
     i = mysql_affected_rows(Sql_Connection);
     //log it
-    do_message(FormatSTLString("%i %s",i,MessageArray[0]));
+    stringstream ss;
+    ss << i << " " << MessageArray[0];
+    do_message(ss.str());
     return i;
 }
 
@@ -1160,7 +1195,9 @@ int CMySql::delete_row(const char*db,const char*table,
     //should be > 0 
     zaehler = mysql_affected_rows(Sql_Connection);
     //log it
-    do_message(FormatSTLString("%lu %s",zaehler,MessageArray[0]));
+    stringstream ss;
+    ss << zaehler << " " << MessageArray[0];
+    do_message(ss.str());
     return zaehler;
 }
 
@@ -1225,7 +1262,9 @@ bool CMySql::delete_table(const char*db, const char*table)
         return false;
     }
     unsigned long zaehler = mysql_affected_rows(Sql_Connection);
-    do_message(FormatSTLString("%lu %s",zaehler,MessageArray[0]));
+    stringstream ss;
+    ss << zaehler << " " << MessageArray[0];
+    do_message(ss.str());
     return true;
 }
 
@@ -1360,7 +1399,7 @@ bool CMySql::alter_table(const char*db, const char*table,ColumnList&n_columns,co
     }
     if (connect_db(db)!=0) {
         do_message("Could not connect to database");
-		return false;
+        return false;
     }
     command = "ALTER TABLE ";
     //command+=db;command+='.';
@@ -1404,8 +1443,10 @@ bool CMySql::alter_table(const char*db, const char*table,ColumnList&n_columns,co
 	}
     }
     for (idx = 0; idx < n_columns.size();++idx) {
-	change_iterator = columns_change.find_second(n_columns[idx].get_name());
-	if (change_iterator) {
+	//change_iterator = columns_change.find_second(n_columns[idx].get_name());
+        change_iterator = find_second(columns_change,n_columns[idx].get_name());
+        
+	if (change_iterator!=columns_change.end()) {
 	    if (!first_statement) {
 		command+=", ";
 	    } else {
@@ -1447,6 +1488,7 @@ bool CMySql::alter_table(const char*db, const char*table,ColumnList&n_columns,co
 int CMySql::build_command(std::string&target,CColumnDescriptor&desc)const
 {
     std::string Type = "";
+    stringstream ss;
     target.resize(0);
     target=desc.get_name();
     target+=" ";
@@ -1469,7 +1511,10 @@ int CMySql::build_command(std::string&target,CColumnDescriptor&desc)const
 	    max_enum = 65535;
 	}
 	if (current_enums.size() > max_enum) {
-	    do_message(FormatSTLString("More than %u %ss are not allowed",max_enum,max_enum==64?"SET":"ENUM"));
+            ss.str("");
+            ss << "More than " << max_enum << (max_enum==64?"SET":"ENUM")
+               << "s are not allowed!";
+	    do_message(ss.str());
 	    return 0;
 	}
 	Type+="(";
@@ -1485,13 +1530,15 @@ int CMySql::build_command(std::string&target,CColumnDescriptor&desc)const
     target+=Type;
     target+=" ";
     if (desc.get_MaxLength()>0 && desc.get_FieldType() != 21 && desc.get_FieldType() != 22) {
-	target+="(";
-	target+=FormatSTLString("%i",desc.get_MaxLength());
+        ss.str("");
+        ss << "("
+           << desc.get_MaxLength();
 	if (desc.get_MaxDecimals() > 0) {
-	    target+=", ";
-	    target+=FormatSTLString("%i",desc.get_MaxDecimals());
+            ss << ", "
+               << desc.get_MaxDecimals();
 	}
-	target+=") ";
+	ss << ") ";
+        target+=ss.str();
     }
     if (desc.is_Unsigned())
 	target+="UNSIGNED ";
@@ -1514,6 +1561,7 @@ int CMySql::build_command(std::string&target,CColumnDescriptor&desc)const
 
 int CMySql::build_key_command(std::string&target,const KeyList*keys,bool add)
 {
+    stringstream ss;
     target.resize(0);
     KeyList::const_iterator key;
     if (keys) {
@@ -1555,17 +1603,19 @@ int CMySql::build_key_command(std::string&target,const KeyList*keys,bool add)
             target+="(";
             pairIlist::iterator iter;
             iter = col_list.begin();
+            ss.str("");
             for (;iter!=col_list.end();++iter) {
                 if (f_count> 0)
-                    target+=",";
+                    ss << ",";
                 ++f_count;
-                target+=iter->first.c_str();
+                ss << iter->first.c_str();
                 if (iter->second > 0) {
-                    target+="(";
-                    target+=FormatSTLString("%u",iter->second);
-                    target+=")";
+                    ss << "("
+                       << iter->second
+                       << ")";
                 }
             }
+            target+=ss.str();
             target+=") ";
         }
     }
@@ -1577,6 +1627,7 @@ bool CMySql::do_statement(const char*statement,stringlist&target,stringlist&size
 {
     sizes.resize(0);
     target.resize(0);
+    headers.resize(0);
 
     if (!Sql_Connection) {
 	do_message(MessageArray[4]);
@@ -1586,6 +1637,7 @@ bool CMySql::do_statement(const char*statement,stringlist&target,stringlist&size
     MYSQL_FIELD*Field;
 
     std::string query;
+    stringstream ss;
 
     MYSQL_RES*Res=0;
     if (!log_errors_only)
@@ -1609,8 +1661,11 @@ bool CMySql::do_statement(const char*statement,stringlist&target,stringlist&size
         return true;
     }
     unsigned long zaehler = Res->row_count;
-    if (!log_errors_only)
-	do_message(FormatSTLString("%lu %s",zaehler,MessageArray[0]));
+    if (!log_errors_only) {
+        ss.str("");
+        ss << zaehler << " " << MessageArray[0];
+	do_message(ss.str());
+    }
     std::string helper;
     std::string entry;
     unsigned int j;
@@ -1657,3 +1712,4 @@ bool CMySql::do_statement(const char*statement,stringlist&target,stringlist&size
     mysql_free_result(Res);
     return true;
 }
+#endif // HAVE_MYSQL_LIBS
