@@ -1,19 +1,19 @@
 // -*-Mode: C++;-*- 
 
-/*
- * $Id: my_sql.h,v 2.30 2001/04/23 22:48:30 ral Exp $
- * Include file for the SQL-Wrapper class
- */
 #ifndef _MYSQL_H
 #define _MYSQL_H
 
+#include "config.h"
+
+#ifdef HAVE_MYSQL_LIBS
+
 #include "PatternPair.h"
 #include "tabledescr.h"
-#include "stringlist.h"
+#include "helpers/stringlist.h"
 #include "sendmessage.h"
 #include "change_type.h"
 #include "my_sql_types.h"
-#include "smart_pointer.h"
+#include "helpers/smart_pointer.h"
 
 struct st_mysql;
 struct st_mysql_res;
@@ -21,6 +21,8 @@ struct st_mysql_res;
 typedef st_mysql MYSQL;
 typedef st_mysql_res MYSQL_RES;
 
+#endif
+
 //! Sql Wrapper class
 /*!
  * This is the wrapper class for the mysql-c-lib
@@ -28,15 +30,21 @@ typedef st_mysql_res MYSQL_RES;
  * It contains the most routins to connect and deal with a sql-server
  *
  * \author Rajko Albrecht
- * \version $Id: my_sql.h,v 2.30 2001/04/23 22:48:30 ral Exp $
+ * \version $Id: my_sql.h,v 2.32 2003/02/04 00:08:53 ral Exp $
  */
-class CMySql:virtual public refCounter
+class CMySql:virtual public ref_count
 {
+#ifdef HAVE_MYSQL_LIBS
 protected:
     //! internal fetch_row
     int _fetch_rows(const char*db,const char*table,const char*sort_by,
                    stringlist*which,unsigned int offset,unsigned int count,
                    PatternList*Pattern,bool errors_only,MYSQL_RES**Res);
+    //! create a INSERT/REPLACE statment
+    /*!
+     * \sa insert_row, replace_row
+     */
+    int insert_replace_row(const std::string what, const char*db,const char*table, PatternList*Pattern);
     //! The connection itself
     MYSQL*Sql_Connection;
     //! a simple blocker
@@ -191,6 +199,15 @@ public:
      * \sa success_connect, sql_disconnect
      */
     void sql_connect(const char*host,const char*user,const char*pass,const char*port);
+    //! Connect to sql server
+    /*!
+     * Connects to a mysql-server with the given parameter
+     * \param host contains the host to connect to, if empty, localhost is used
+     * \param user the user - if empty, current loginname is used
+     * \param pass password of the user at host
+     * \param port the port the class should use. If connect to the localhost  via unix-socket, unused
+     * \sa success_connect, sql_disconnect
+     */
     void sql_connect(const std::string&host,const std::string&user,
 		     const std::string&pass,const std::string&port);
     //! Disconnect
@@ -209,15 +226,15 @@ public:
     //! Serverstatus
     /*!
      * Returns the current status of the server (threads, open tables etc.)
-     * in a zero-terminated string
+     * as String
      */
-    char*get_status();
+    std::string get_status();
     //! Get last error information
     /*!
       returns the last error statement. Most of them will printed out via the messagehandler.
      \sa set_message_call_back
     */
-    char*get_last_error()const;
+    std::string get_last_error()const;
     //! connection status
     /*!
      returns the connection status of the class
@@ -263,9 +280,18 @@ public:
       returns a list of columns in a table
       \param db Database to use
       \param table table to use
-      \return Pointer to a ColumnList or 0 if failure
+      \param target target list to fill
+      \return true if success or false if failure
     */
     bool get_table_fields(const char*db,const char*table,ColumnList&target)const;
+    //! Key list
+    /*!
+      returns a list of keys of a table
+      \param db Database to use (if db == 0, last used db will used again)
+      \param table table the keys are wanted
+      \param target where to store the key list
+      \return true if success false if failure
+    */
     bool get_table_keys(const char*db, const char*table, KeyList&target)const;
     /**
      * Creates a new database
@@ -313,8 +339,23 @@ public:
       * \param table the table where to insert, can not be blank
       * \param Pattern a list of columnname-value pairs to insert into the table
       * \return 0 if success, -1 if error
+      * \sa replace_row
       */
-    int insert_row(const char*db,const char*table, PatternList*Pattern);
+    int insert_row(const char*db,const char*table, PatternList*Pattern)
+    { return insert_replace_row("INSERT",db,table,Pattern);}
+    //!inserts a new row into table "table" in database db.
+     /*!
+      * It using the "REPLACE INTO" instead of "INSERT INTO" and will so replace existing entries
+      * with the same key.
+      * \param db the database, if empty, current is used
+      * \param table the table where to insert, can not be blank
+      * \param Pattern a list of columnname-value pairs to insert into the table
+      * \return 0 if success, -1 if error
+      * \sa insert_row
+      */
+    int replace_row(const char*db,const char*table, PatternList*Pattern)
+    { return insert_replace_row("REPLACE",db,table,Pattern);}
+
     //! modifies a row
     /*!
      * \param db the database to use, if 0, current is used
@@ -387,14 +428,20 @@ public:
      */    
     bool do_statement(const char*statement,stringlist&target,stringlist&sizes,stringlist&headers,
 		      bool log_error_only = false);
+#else
+    CMySql(){}
+    virtual ~CMySql(){};
+#endif
 };
 
+#ifdef HAVE_MYSQL_LIBS
 inline CMySql::CMySql(const char*host,const char*user,const char*pass,const char*port)
 {
     Sql_Connection = 0L;
     message_call_back = 0;
     sql_connect(host,user,pass,port);
 }
+#endif
 
 #endif
 
