@@ -1,10 +1,15 @@
-// $Id: progressdlg.cpp,v 2.3 2001/04/16 13:01:09 ral Exp $
+// $Id: progressdlg.cpp,v 2.4 2001/09/24 17:11:13 ral Exp $
 #ifndef rcsid
-static const char rcsid[]="$Id: progressdlg.cpp,v 2.3 2001/04/16 13:01:09 ral Exp $";
+static const char rcsid[]="$Id: progressdlg.cpp,v 2.4 2001/09/24 17:11:13 ral Exp $";
+#endif
+
+#ifndef WIN32
+#include "kapp.h"
+#else
+#include "qapp.h"
 #endif
 
 #include "progressdlg.h"
-#include "kapp.h"
 #include <qlabel.h>
 #include <kprogress.h>
 
@@ -46,7 +51,11 @@ void CProgressDlg::setPos(int pos)
     if (cur != m_current) {
 	m_current = cur;
 	m_Progress->setValue(cur);
+#ifndef WIN32
 	KApplication::kApplication()->processEvents(10);
+#else
+    qApp->processEvents(10);
+#endif
     }
 }
 
