@@ -1,6 +1,6 @@
 // -*- Mode: C++; -*-
 
-#include "stringlist.h"
+#include "kmysqladmin/helpers/stringlist.h"
 
 class CScriptSplit
 {
