@@ -23,12 +23,12 @@ public:
 		       const std::string port,const std::string pass);
     bool RetrieveLastLogin(std::string&user,std::string&host,
 			   std::string&port,std::string&pass);
-    void set_fixed_font( const std::string name, const int size, const int weight, const bool italic, const int charset);
+    void set_fixed_font( const std::string name, const int size, const int weight, const bool italic);
     void set_fixed_font( const QFont&fnt);
-    void set_nprop_font( const std::string name, const int size, const int weight, const bool italic, const int charset);
+    void set_nprop_font( const std::string name, const int size, const int weight, const bool italic);
     void set_nprop_font( const QFont&fnt);
 
-    void get_fixed_font(std::string&name, int&size, int&weight, bool&italic, int&charset);
+    void get_fixed_font(std::string&name, int&size, int&weight, bool&italic);
 
     QFont get_fixed_font();
     QFont get_nonprop_font();
